@@ -78,7 +78,6 @@ def get_dvcurl():
             if ln.startswith("url="):
               dvc_url.append(ln)
     except:
-        print('No .dvc/config.local was found.')
         try:
           with open(str(Path(".dvc/config")), "r") as fi:
             for ln in fi:
@@ -86,7 +85,7 @@ def get_dvcurl():
                 if ln.startswith("url="):
                   dvc_url.append(ln)
         except:
-          print('No .dvc/config was found.')
+          print('No .dvc/config or .dvc/config.local was found.')
 
     if len(dvc_url) != 1:
       if len(dvc_url) == 0:
@@ -223,30 +222,14 @@ def exec_branch(dvc_files, branch_name, project_dir, no_exec, num_of_repeats, li
 
     dvc_url, dvc_server, dvc_path = get_dvcurl()
 
-    data_username, data_server, data_path = get_mount_values_for_a_direcotry(project_dir + '/data')
+    project_dir = get_main_git_directory_Path()
+    path_to_sshfs_json = str(Path(os.path.join(project_dir, '.dvc_cc/sshfs.json')))
 
-    # TODO: The following should be the only way to use SSHFS!
-    # TODO: It should also be possible to use other folders than the data folder
-    if data_server is None:
-        # Try to read the SSHFS-Connection via the .dvc_cc/sshfs.json file!
-
-        project_dir = get_main_git_directory_Path()
-        path_to_sshfs_json = str(Path(os.path.join(project_dir, '.dvc_cc/sshfs.json')))
-
-        if os.path.exists(path_to_sshfs_json):
-            with open(path_to_sshfs_json, "r") as jsonFile:
-                data = json.load(jsonFile)
-
-            if 'data' in data.keys():
-                print('Hint: The external server use SSHFS to the data folder. Currently you do not have a SSHFS connection'
-                      ' to this folder. If you wish to activate this SSHFS connection you can use: "dvc-cc sshfs r[econnect]"'
-                      )
-                data_username = data["data"]["username"]
-                data_server = data["data"]["server"]
-                data_path = data["data"]["remote_path"]
-
-    data_password = '{{' + str(data_server).replace('.', '_').replace('-', '_') + '_password}}'
-    use_external_data_dir = data_server is not None
+    if os.path.exists(path_to_sshfs_json):
+        with open(path_to_sshfs_json, "r") as jsonFile:
+            sshfs_data = json.load(jsonFile)
+    else:
+        sshfs_data = None
 
     with open('cc_execution_file.red.yml',"w") as f:
         print("batches:", file=f)
@@ -277,19 +260,41 @@ def exec_branch(dvc_files, branch_name, project_dir, no_exec, num_of_repeats, li
             print("      dvc_servername: \"" + dvc_server + "\"", file=f)
             print("      dvc_path_to_working_repository: \"" + dvc_path + "\"", file=f)
 
-            if use_external_data_dir:
-                print("      dvc_data_dir:", file=f)
-                print("        class: Directory", file=f)
-                print("        connector:", file=f)
-                print("            command: \"red-connector-ssh\"", file=f)
-                print("            mount: true", file=f)
-                print("            access:", file=f)
-                print("              host: '" + data_server + "'", file=f)
-                print("              port: 22", file=f)
-                print("              auth:", file=f)
-                print("                username: '" + data_username + "'", file=f)
-                print("                password: '" + data_password + "'", file=f)
-                print("              dirPath: '" + data_path + "'", file=f)
+            if sshfs_data is not None:
+                print("      sshfs_input_server_settings:", file=f)
+                print("        [", file=f)
+                for i in range(len(sshfs_data.keys)):
+                    sshfs_dest_rel = sshfs_data[i]
+                    sshfs_username = sshfs_data[sshfs_dest_rel]["username"]
+                    sshfs_server = sshfs_data[sshfs_dest_rel]["server"]
+                    sshfs_path = sshfs_data[sshfs_dest_rel]["remote_path"]
+                    sshfs_password = '{{' + str(sshfs_server).replace('.', '_').replace('-', '_') + '_password}}'
+
+                    print("          class: Directory", file=f)
+                    print("          connector:", file=f)
+                    print("              command: \"red-connector-ssh\"", file=f)
+                    print("              mount: true", file=f)
+                    print("              access:", file=f)
+                    print("                host: '" + sshfs_server + "'", file=f)
+                    print("                port: 22", file=f)
+                    print("                auth:", file=f)
+                    print("                  username: '" + sshfs_username + "'", file=f)
+                    print("                  password: '" + sshfs_password + "'", file=f)
+                    if i+1 < len(sshfs_data.keys):
+                        print("                dirPath: '" + sshfs_path + "',", file=f)
+                    else:
+                        print("                dirPath: '" + sshfs_path + "'", file=f)
+                print("        ]", file=f)
+
+                print("      sshfs_input_dest_rel_paths:", file=f)
+                print("        [", file=f)
+                for i in range(len(sshfs_data.keys)):
+                    sshfs_dest_rel = sshfs_data[i]
+                    if i+1 < len(sshfs_data.keys):
+                        print("        '"+sshfs_dest_rel+"',", file=f)
+                    else:
+                        print("        '"+sshfs_dest_rel+"'", file=f)
+                print("        ]", file=f)
 
             print("      dvc_remote_directory_sshfs:", file=f)
             print("        class: Directory", file=f)
@@ -617,7 +622,10 @@ def main():
             draw = hyperopt_draws[i]
             if len(draw) > 0: # one or more hyperparameters was set!
                 branch_name = branch_names[i]
-                subprocess.call(['git', 'checkout', '-q', '-b', branch_name])
+                if len(branch_names) == 1: # use only one input branch, if only one experiment exists
+                    subprocess.call(['git', 'checkout', '-q', branch_name])
+                else: # create new input branches for each experiment
+                    subprocess.call(['git', 'checkout', '-q', '-b', branch_name])
                 print(bcolors.BOLD + 'Create an hyperopt-input git-branch: ' + branch_name + bcolors.ENDC)
 
                 # TODO: HYPEROPT-FILES TO DVC WITH SETTED PARAMETERS #
